@@ -6,9 +6,18 @@ OC.L10N.register(
     "No file provided for import" : "Δεν δόθηκε αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
     "A Bookmark manager for Nextcloud" : "Διαχειριστής σελιδοδεικτών του Nextcloud",
+    "Select bookmark" : "Επιλογή σελιδοδείκτη",
     "Details" : "Λεπτομέρειες",
+    "Rename" : "Μετονομασία",
+    "Move" : "Μετακίνηση",
     "Delete" : "Διαγραφή",
+    "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
     "Save" : "Αποθήκευση",
+    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
+    "New folder" : "Νέος φάκελος",
+    "Move selection" : "Μετακίνηση επιλογής",
+    "Delete selection" : "Διαγραφή επιλογής",
+    "Enter a link" : "Εισάγετε σύνδεσμο",
     "Recently added" : "Προστέθηκαν πρόσφατα",
     "Most visited" : "Πιο δημοφιλή",
     "RSS Feed" : "Ροή RSS",
