@@ -2,17 +2,12 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Marcadores",
-    "Bookmarklet" : "Marcadores",
-    "Error" : "Error",
-    "Import completed successfully." : "Importar completado con éxito",
     "Failed to import one bookmark, because: " : "Fallo al importar un marcador, porque:",
     "No file provided for import" : "No se proporcionó ningún archivo para importar",
     "Unsupported file type for import" : "Tipo de archivo no admitido para importar",
+    "Save" : "Guardar",
+    "Bookmarklet" : "Marcadores",
     "Add a bookmark" : "Agregar un marcador",
-    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Desea sobreescribir?",
-    "The title of the page" : "El título de la página",
-    "The address of the page" : "La dirección de la página",
-    "Description of the page" : "Descripción de la página",
-    "Save" : "Guardar"
+    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Desea sobreescribir?"
 },
 "nplurals=2; plural=(n != 1);");
