@@ -5,14 +5,9 @@ OC.L10N.register(
     "Failed to import one bookmark, because: " : "ერთი სანიშნის იმპორტი ვერ მოხერხდა, რადგან:",
     "No file provided for import" : "იმპორტისთვის ფაილი არაა მოწოდებული",
     "Unsupported file type for import" : "იმპორტისთვის მხარდაუჭერელი ფაილის სახეობა",
+    "Save" : "შენახვა",
     "Bookmarklet" : "Bookmarklet-ი",
-    "Error" : "შეცდომა",
-    "Import completed successfully." : "იმპორტი წარმატებით დასრულდა.",
     "Add a bookmark" : "სანიშნის დამატება",
-    "This URL is already bookmarked! Overwrite?" : "ეს URL უკვე მონიშნულია! გადავწეროთ?",
-    "The title of the page" : "გვერდის სახელი",
-    "The address of the page" : "გვერდის მისამართი",
-    "Description of the page" : "გვერდის აღწერილობა",
-    "Save" : "შენახვა"
+    "This URL is already bookmarked! Overwrite?" : "ეს URL უკვე მონიშნულია! გადავწეროთ?"
 },
 "nplurals=2; plural=(n!=1);");
