@@ -8,18 +8,29 @@ OC.L10N.register(
     "Unsupported file type for import" : "不支持导入的文件类型",
     "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
     "This app provides you with a web interface for collecting and organizing bookmarks to the sites on the web that are precious to you. You can browse and filter your bookmarks via tags and folders and by using the built-in search feature. Furthermore, in order to access your bookmarks anywhere, it also allows you to synchronize third-party clients via a built-in REST API -- in your browsers and on your phone.\n\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "此应用为您提供一个Web界面，用于收集和组织对您有价值的网站书签。您可以通过标签和文件夹来浏览和过滤您的书签并使用内置的搜索功能。另外，为使您能从任何地点访问您的书签，它允许您通过内建的REST API与第三方客户端同步——在您的浏览器和您的手机上。\n\n请在这里查看第三方客户端：https://github.com/nextcloud/bookmarks#third-party-clients",
+    "Select bookmark" : "选择书签",
     "Details" : "详情",
     "Rename" : "重命名",
     "Move" : "移动",
     "Delete" : "删除",
     "Enter bookmark title" : "输入书签标题",
     "Save" : "保存",
+    "No bookmarks here" : "无书签",
+    "Try changing your query or add some using the button on the left." : "使用左边的按钮尝试更改或增加您的查询",
     "Select one or more tags" : "选择一个或多个标签",
     "New folder" : "新建文件夹",
+    "Grid view" : "网格视图",
+    "List view" : "列表视图",
+    "Move selection" : "移动选择项",
+    "Delete selection" : "删除选择项",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["选择了%n个书签"],
     "Enter a link" : "输入一个链接",
     "Create" : "创建",
     "Enter folder title" : "输入文件夹标题",
     "Root folder" : "根文件夹",
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移动%n个文件夹和一些书签"],
+    "_Moving %n folder_::_Moving %n folders_" : ["正在移动%n个文件夹"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移动%n个书签"],
     "New Bookmark" : "新建书签",
     "All Bookmarks" : "所有书签",
     "Recent Bookmarks" : "近期书签",
@@ -32,10 +43,14 @@ OC.L10N.register(
     "Most visited" : "访问最多",
     "Last modified" : "上一次更改",
     "RSS Feed" : "RSS ",
+    "This is an RSS feed of the current result set with access restricted to you." : "这是当前结果集的RSS订阅，限制为只有您能访问。",
     "Clear data" : "清除数据",
+    "Permanently remove all bookmarks from your account. There is no going back!" : "永久删除您账号中的所有书签。此操作无法恢复！",
     "Delete all bookmarks" : "删除所有书签",
     "Bookmarklet" : "小书签",
+    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "将此拖拽至你的浏览器书签，点击它即可将页面快速保存为书签",
     "Add to {instanceName}" : "添加到 {instanceName}",
+    "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
     "Client apps" : "客户端应用",
     "Do you really want to delete all your bookmarks?" : "您确定准备好删除所有的书签吗？",
     "Creation date" : "创建日期",
@@ -46,11 +61,17 @@ OC.L10N.register(
     "{time} ago" : "{time} 之前",
     "Select" : "选择",
     "Previews" : "预览",
+    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "为了显示您书签网站的真实截图，书签应用使用第三方服务生成截图。",
     "Screeenly" : "Screeenly",
+    "You can either sign up for free at screeenly.com or setup your own server." : "您既可以在 screeenly.com 免费注册，也可以搭建您自己的服务器。",
     "Screeenly API URL" : "Screenly API 地址",
     "Screeenly API key" : "Screenly API 密钥",
     "Privacy" : "隐私",
+    "Bookmarks will try to access web pages that you add to automatically add information about them." : "书签应用将访问您添加的网页以自动获取关于它们的信息。",
+    "Enable accessing and collecting information from the web pages you add" : "启用从您添加的网页访问和搜集信息的功能",
     "Performance" : "性能",
+    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "在一个有很多用户的安装实例中，对每个账号的书签数量进行限制可能比较有用。",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每个账号允许的最大书签数量。（0为无限制；默认为无限制）",
     "Failed to load settings" : "无法加载设置",
     "Failed to save settings" : "无法保存设置",
     "Add a bookmark" : "添加书签",
@@ -68,6 +89,7 @@ OC.L10N.register(
     "Failed to delete folder" : "无法删除文件夹",
     "Failed to create folder" : "无法创建文件夹",
     "Failed to move parts of selection" : "无法移动部分选择项",
+    "Failed to delete parts of selection" : "无法删除部分选择项",
     "Failed to fetch bookmarks." : "无法获取书签",
     "Failed to change setting" : "无法修改设置",
     "Failed to load setting " : "无法加载设置",
