@@ -183,7 +183,7 @@ class BookmarkController extends ApiController {
 
 		if (!$this->userId) {
 			if ($this->request->getHeader('Authorization')) {
-				list($method, $credentials) = explode(' ', $this->request->getHeader('Authorization'));
+				[$method, $credentials] = explode(' ', $this->request->getHeader('Authorization'));
 			} else {
 				$res = new DataResponse(['status' => 'error', 'data' => 'Unauthorized'], Http::STATUS_UNAUTHORIZED);
 				$res->addHeader('WWW-Authenticate', 'Basic realm="Nextcloud", charset="UTF-8"');
@@ -194,7 +194,7 @@ class BookmarkController extends ApiController {
 				$res->addHeader('WWW-Authenticate', 'Basic realm="Nextcloud", charset="UTF-8"');
 				return $res;
 			} else {
-				list($username, $password) = explode(':', base64_decode($credentials));
+				[$username, $password] = explode(':', base64_decode($credentials));
 				if (false === $this->userSession->login($username, $password)) {
 					$res = new DataResponse(['status' => 'error', 'data' => 'Unauthorized'], Http::STATUS_UNAUTHORIZED);
 					$res->addHeader('WWW-Authenticate', 'Basic realm="Nextcloud", charset="UTF-8"');
@@ -285,18 +285,20 @@ class BookmarkController extends ApiController {
 	}
 
 	/**
-	 * @param string $url
+     * @param string $url
 	 * @param array $item
 	 * @param string $title
 	 * @param bool $is_public
 	 * @param string $description
+	 * @param array $tags
+	 * @param array $folders
 	 * @return JSONResponse
 	 *
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
 	 * @CORS
 	 */
-	public function newBookmark($url = "", $item = [], $title = null, $is_public = false, $description = "", $tags = [], $folders = null) {
+	public function newBookmark($url = "", $item = [], $title = null, $is_public = false, $description = "", $tags = [], $folders = []) {
 		if (isset($title)) {
 			$title = trim($title);
 		}
@@ -508,33 +510,36 @@ class BookmarkController extends ApiController {
 
 	/**
 	 *
+	 * @param int $folder The id of the folder to import into
 	 * @return \OCP\AppFramework\Http\JSONResponse
 	 *
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
 	 * @CORS
 	 */
-	public function importBookmark() {
+	public function importBookmark($folder=-1) {
 		$full_input = $this->request->getUploadedFile("bm_import");
 
+		$result = ['errors' => []];
 		if (empty($full_input)) {
-			$this->logger->warn("No file provided for import", ['app' => 'bookmarks']);
-			$error = [];
-			$error[] = $this->l10n->t('No file provided for import');
+			$result['errors'][] = $this->l10n->t('No file provided for import');
 		} else {
-			$error = [];
 			$file = $full_input['tmp_name'];
 			if ($full_input['type'] === 'text/html') {
-				$error = $this->bookmarks->importFile($this->userId, $file);
-				if (empty($error)) {
-					return new JSONResponse(['status' => 'success']);
+				$result = $this->bookmarks->importFile($this->userId, $file, $folder);
+				if (count($result['errors']) === 0) {
+					return new JSONResponse([
+						'status' => 'success',
+						'data' => $result['children']
+					]);
 				}
 			} else {
-				$error[] = $this->l10n->t('Unsupported file type for import');
+				$result['errors'][] = $this->l10n->t('Unsupported file type for import');
 			}
 		}
 
-		return new JSONResponse(['status' => 'error', 'data' => $error]);
+		$this->logger->warning(var_export($result['errors'], true), ['app' => 'bookmarks']);
+		return new JSONResponse(['status' => 'error', 'data' => $result['errors']]);
 	}
 
 	/**
