@@ -25,12 +25,6 @@ module.exports = {
 				test: /\.scss$/,
 				use: ['vue-style-loader', 'css-loader', 'sass-loader']
 			},
-			{
-				test: /\.(js|vue)$/,
-				use: 'eslint-loader',
-				exclude: /node_modules/,
-				enforce: 'pre'
-			},
 			{
 				test: /\.vue$/,
 				loader: 'vue-loader',
@@ -42,7 +36,10 @@ module.exports = {
 				use: {
 					loader: 'babel-loader',
 					options: {
-						presets: ['@babel/preset-env']
+						presets: [['@babel/preset-env', {
+      targets: '> 0.25%, not dead',
+      useBuiltIns: "usage",
+    }]]
 					}
 				}
 			}
